@@ -16,7 +16,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.57 2004/02/12 23:57:17 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.61 2004/03/03 04:58:04 muppetman Exp $
 #
 
 package Gtk2;
@@ -31,7 +31,7 @@ use Glib;
 
 require DynaLoader;
 
-our $VERSION = '1.035';
+our $VERSION = '1.038';
 
 our @ISA = qw(DynaLoader);
 
@@ -64,6 +64,15 @@ Gtk2->bootstrap ($VERSION);
 
 # Preloaded methods go here.
 
+package Gtk2::Gdk;
+
+sub CHARS { 8 };
+sub SHORTS { 16 };
+sub LONGS { 32 };
+
+sub USHORTS { 16 };
+sub ULONGS { 32 };
+
 package Gtk2::Gdk::Atom;
 
 use overload
@@ -161,7 +170,7 @@ The gtk2-perl team:
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2003 by the gtk2-perl team.
+Copyright 2003-2004 by the gtk2-perl team.
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public
