@@ -21,7 +21,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/calendar.pl,v 1.5 2003/09/22 00:04:23 rwmcfa1 Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/calendar.pl,v 1.6 2004/01/25 06:52:01 muppetman Exp $
 #
 
 # this was originally gtk-2.2.1/examples/buttonbox/buttonbox.c
@@ -30,8 +30,7 @@
 use strict;
 use Gtk2;
 
-use constant TRUE => 1;
-use constant FALSE => 0;
+use Glib ':constants';
 
 use constant DEF_PAD => 10;
 use constant DEF_PAD_SMALL => 5;
