@@ -18,7 +18,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/histogramplot.pl,v 1.9 2003/11/08 06:23:57 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/examples/histogramplot.pl,v 1.10 2004/01/25 06:52:01 muppetman Exp $
 #
 
 # originally written in C by muppet in 2001 or 2002, i can't remember.
@@ -26,13 +26,10 @@
 
 package Histogram::Plot;
 
-use Gtk2;
 use warnings;
 use strict;
-use Data::Dumper;
-
-use constant FALSE => 0;
-use constant TRUE => 1;
+use Glib qw/TRUE FALSE/;
+use Gtk2;
 
 use constant MIN_CHART_WIDTH  => 256;
 use constant MIN_CHART_HEIGHT => 100;
@@ -530,9 +527,8 @@ sub do_threshold_changed {
 #
 package main;
 
-use Gtk2 qw/-init -locale/;
-use constant TRUE => 1;
-use constant FALSE => 0;
+use Glib qw/TRUE FALSE/;
+use Gtk2 qw/-init/;
 
 my $window = Gtk2::Window->new;
 $window->signal_connect (delete_event => sub { Gtk2->main_quit; FALSE });
