@@ -18,7 +18,7 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
  * 
  *
- * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.25 2004/02/05 21:46:56 kaffeetisch Exp $
+ * $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/gtk2perl.h,v 1.26 2004/02/19 11:50:37 kaffeetisch Exp $
  */
 
 #ifndef _GTK2PERL_H_
@@ -84,13 +84,18 @@ GtkTargetEntry * SvGtkTargetEntry (SV * sv);
 void gtk2perl_read_gtk_target_entry (SV * sv, GtkTargetEntry * entry);
 
 #define GTK2PERL_STACK_ITEMS_TO_TARGET_ENTRY_ARRAY(first, targets, ntargets) \
-	{							\
-	guint i;						\
-	ntargets = items - first;				\
-	targets = gperl_alloc_temp (sizeof (GtkTargetEntry) * ntargets); \
-	for (i = 0 ; i < ntargets ; i++)			\
-		gtk2perl_read_gtk_target_entry (ST (i + first),	\
-		                                targets + i);	\
+	{							        \
+	guint i;						        \
+	if (items <= first) {                                           \
+		ntargets = 0;                                           \
+		targets = NULL;                                         \
+	} else {                                                        \
+		ntargets = items - first;				\
+		targets = gperl_alloc_temp (sizeof (GtkTargetEntry) * ntargets); \
+		for (i = 0 ; i < ntargets ; i++)			\
+			gtk2perl_read_gtk_target_entry (ST (i + first),	\
+			                                targets + i);	\
+		}                                                       \
 	}
 
 /* 
